# Command-line interface

`measured` also includes a command-line utility for exploring and converting units.

```bash
$ measured "3 rod"
Magnitude: 3
Unit: rod
Dimension: length
Defined conversions:
25.0 link
16.5 US survey foot
5.029210058420117 meter
0.25 chain
```
